︠e9920be7-01d9-4601-91e0-b7495080428f︠
var('x t psi a w xd epsilon')
︡2258b775-346f-4097-95bf-a46f771cdc7b︡{"html": "<span class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left(x, t, \\psi, a, w, \\mbox{xd}, \\epsilon\\right)</span>"}︡
︠7c22af52-8b82-45f6-bb59-f314900e989e︠
def duffing_first_asymp(func):
    """ a function for evaluating first asymptotic approximation of solution for Duffing's equation
        via use of Krilov-bogolyubov method.
    Accepts 1 arguments:
        \param1 a function, which is dependent on 2 variables, for example
                f(u,ud)=u^2-ud^5/4, where u -- is a time-depenent function u(t)
                in Duffing's equation and ud -- it's derivative: ud(t)=du/dt
    """
    
    
    a = var('a')
    epsilon = var('epsilon')
    psi=var('psi')
    t=var('t')
    u=var('u')
    ud=var('ud')
    def f1(a):
        return 1/pi*integrate(sin(psi)*func(a*cos(psi),-a*w*sin(psi)),psi,0,2*pi)
    def g1(a):
        return 1/pi*integrate(cos(psi)*func(a*cos(psi),-a*w*sin(psi)),psi,0,2*pi)
    def dadt(t):
        return -epsilon/(2*w)*f1(a)
    def dpsidt(t):
        return -epsilon/(2*w)*g1(a)
    print "Krilov-Bogolyubov first asymp. approximation for equation:\n u''+w^2*u=epsilon*f(u,u');\n f(u,ud)=",f(u,ud)
    print '\n results:'
    print 'da/dt(t)='
    show(dadt(t))
    print 'dpsi/dt(t)='
    show(dpsidt(t))
    print 'u(t)=a(t)*cos(psi(t))'
︡74abee3e-60eb-43fc-8403-a31c2c8a8bd6︡︡
︠8053576e-c60a-4f79-b3c4-af92fefbf1d9︠
print "problem 1:  x''+3x+1/2x^3+1/2x^5=0"
print "epsilon=1/2"

def f(x,xd):
    return -(x^3+2/3*x^5)
print "f(x,xd)=",f(x,xd)
duffing_first_asymp(f)
︡8c2b65dd-052c-4f09-9246-3e279576ee2d︡{"stdout": "problem 1:  x''+3x+1/2x^3+1/2x^5=0\nepsilon=1/2\nf(x,xd)= -2/3*x^5 - x^3\nKrilov-Bogolyubov first asymp. approximation for equation:\n u''+w^2*u=epsilon*f(u,u');\n f(u,ud)= -2/3*u^5 - u^3\n\n results:\nda/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "dpsi/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{{\\left(5 \\, \\pi a^{5} + 9 \\, \\pi a^{3}\\right)} \\epsilon}{24 \\, \\pi w}</div>"}︡{"stdout": "u(t)=a(t)*cos(psi(t))"}︡
︠977fd6eb-446b-4140-b54b-5780505c97b2︠
def krilov_bogolyubov_second_noxd(func,NMAX):
    """
    A function for evaluating second asymptotic approximation of solution for Duffing equation
    u''+w^2*u=epsilon*f(u).
    where arbitrary function F(x,x') depends only on x: x->F(x) .
    by Krilov-bogolyubov method.
    Accepts 2 arguments:
        \param1 a function and its derivative, function is dependent on 1 variable only,
                for example f(u)=u^2, where u -- is a time-depenent function u(t) in Duffing's
                equation
        \param2 Number of maximal possible fourier series approximation.
        
     What is the output?
     It gives you these expressions
     da(t)/dt = epsilon*A1+epsilon^2*A2    ----> whereas a(t)=solution of this diff. eq.(you have to solve)
     dpsi(t)/dt = w+epsilon*B1+epsilon^2*B2  ----> whereas psi(t)=solution of this diff. eq.(you have to solve)
     u1(psi(t)) is calculated
     
     Finally aysmptotic aproximation of solution is given by formula:
         x(t)=a(t)*cos(psi(t))+u1(psi(t))
    """
    
    
    a = var('a')
    w = var('w')
    epsilon = var('epsilon')
    psi=var('psi')
    t=var('t')
    u=var('u')
    ud=var('ud')
    
    print "Krilov-Bogolyubov secondt approximation for equation:\n d^2 u/dt+w^2*u=epsilon*f(u);\n f(u)=",func(u)
    
    CN=[ ]
    for n in range(NMAX):
        CN.append(1/pi*integrate(func(a*cos(psi))*cos(n*psi),psi,0,2*pi))
    if len(CN)<1:
        CN.append(0)
    CN[0]=1/(2*pi)*integrate(func(a*cos(psi)),psi,0,2*pi)
    print 'Cn[i]='
    show(CN)
    GN = [ ]
    for n in range(NMAX):
        GN.append(-1*CN[n])
    print 'gn='
    show(GN)
    HN = []
    for n in range(NMAX):
        HN.append(0)
    A1=0
    B1=CN[1]/(2*w*a)
    print 'A1='
    show(A1)
    print 'B1='
    show(B1)
    
    def u1(a,psi):
        res=0
        for n in range(NMAX):
            if n!=1:
                res+=CN[n]*cos(n*psi)/(n^2-1)
        return res/w^2
    print 'u1(a,psi)='
    show(u1(a,psi))
    
    func_dx = diff(func)
    
    A2=0
    B2=-1/(2*w)*(CN[1]/(2*w*a))^2
    for n in range(NMAX):
        if n!=1 :
            B2+= 1/(2*w*pi*a)*CN[n]/(w^2*(n^2-1))*integrate(func_dx(a*cos(psi))*cos(psi)*cos(n*psi),psi,0,2*pi)
    print 'A2='
    show (A2)
    print 'B2='
    show (B2)
    
    def dadt(t):
        return 0
    def dpsidt(t):
        return w+epsilon*B1+epsilon^2*B2
    def psiint(t):
        return dpsidt(t).integrate(t)
    
    print '\nRESULTS:'
    print 'da/dt(t)='
    show(dadt(t))
    print 'dpsi/dt(t)='
    show(dpsidt(t))
    
    """resulting function x(t)"""     
    def resu(a,psi):
        sum=0
        for n in range(2,NMAX):
            sum+=epsilon/w^2*CN[n]*cos(n*psi)/(n^2-1)
        return a*cos(psi)-epsilon*CN[0]/w^2+sum
    print 'x(t)='
    show(resu(a,psi))
    
    print 'where a(t) and psi(t) are obtained from equations above'
    print 'psi(t)='
    show(psiint(t))
    return [A1,B1,A2,B2]
︡bb1ca6fe-5a19-44ff-8cb0-34441ef5aebc︡︡
︠b1680cc8-0130-4471-85f3-4dfc4a32490b︠
print "========================================"
print "|| equation1: x''+3x+1/2x^3+1/2x^5=0    "
print "========================================"
print "epsilon=1/2"
f(x)=(x^3+2/3*x^5)
print "f(x,xd)=",f(x)
show(f(x))
krilov_bogolyubov_second_noxd(f,10)
︡d10f312d-235a-4343-a190-f402671d95d2︡{"stdout": "========================================\n|| equation1: x''+3x+1/2x^3+1/2x^5=0    \n========================================\nepsilon=1/2\nf(x,xd)= 2/3*x^5 + x^3"}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{2}{3} \\, x^{5} + x^{3}</div>"}︡{"stdout": "Krilov-Bogolyubov secondt approximation for equation:\n d^2 u/dt+w^2*u=epsilon*f(u);\n f(u)= 2/3*u^5 + u^3\nCn[i]="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[0, \\frac{5 \\, \\pi a^{5} + 9 \\, \\pi a^{3}}{12 \\, \\pi}, 0, \\frac{5 \\, \\pi a^{5} + 6 \\, \\pi a^{3}}{24 \\, \\pi}, 0, \\frac{1}{24} \\, a^{5}, 0, 0, 0, 0\\right]</div>"}︡{"stdout": "gn="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[0, -\\frac{5 \\, \\pi a^{5} + 9 \\, \\pi a^{3}}{12 \\, \\pi}, 0, -\\frac{5 \\, \\pi a^{5} + 6 \\, \\pi a^{3}}{24 \\, \\pi}, 0, -\\frac{1}{24} \\, a^{5}, 0, 0, 0, 0\\right]</div>"}︡{"stdout": "A1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "B1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{5 \\, \\pi a^{5} + 9 \\, \\pi a^{3}}{24 \\, \\pi a w}</div>"}︡{"stdout": "u1(a,psi)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{a^{5} \\cos\\left(5 \\, \\psi\\right) + \\frac{3 \\, {\\left(5 \\, \\pi a^{5} + 6 \\, \\pi a^{3}\\right)} \\cos\\left(3 \\, \\psi\\right)}{\\pi}}{576 \\, w^{2}}</div>"}︡{"stdout": "A2="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "B2="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{5 \\, a^{8}}{27648 \\, w^{3}} + \\frac{{\\left(25 \\, \\pi a^{4} + 18 \\, \\pi a^{2}\\right)} {\\left(5 \\, \\pi a^{5} + 6 \\, \\pi a^{3}\\right)}}{9216 \\, \\pi^{2} a w^{3}} - \\frac{{\\left(5 \\, \\pi a^{5} + 9 \\, \\pi a^{3}\\right)}^{2}}{1152 \\, \\pi^{2} a^{2} w^{3}}</div>"}︡{"stdout": "RESULTS:\nda/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "dpsi/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{1}{27648} \\, {\\left(\\frac{5 \\, a^{8}}{w^{3}} + \\frac{3 \\, {\\left(25 \\, \\pi a^{4} + 18 \\, \\pi a^{2}\\right)} {\\left(5 \\, \\pi a^{5} + 6 \\, \\pi a^{3}\\right)}}{\\pi^{2} a w^{3}} - \\frac{24 \\, {\\left(5 \\, \\pi a^{5} + 9 \\, \\pi a^{3}\\right)}^{2}}{\\pi^{2} a^{2} w^{3}}\\right)} \\epsilon^{2} + w + \\frac{{\\left(5 \\, \\pi a^{5} + 9 \\, \\pi a^{3}\\right)} \\epsilon}{24 \\, \\pi a w}</div>"}︡{"stdout": "x(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{a^{5} \\epsilon \\cos\\left(5 \\, \\psi\\right)}{576 \\, w^{2}} + a \\cos\\left(\\psi\\right) + \\frac{{\\left(5 \\, \\pi a^{5} + 6 \\, \\pi a^{3}\\right)} \\epsilon \\cos\\left(3 \\, \\psi\\right)}{192 \\, \\pi w^{2}}</div>"}︡{"stdout": "where a(t) and psi(t) are obtained from equations above\npsi(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{1}{27648} \\, {\\left({\\left(\\frac{5 \\, a^{8}}{w^{3}} + \\frac{3 \\, {\\left(25 \\, \\pi a^{4} + 18 \\, \\pi a^{2}\\right)} {\\left(5 \\, \\pi a^{5} + 6 \\, \\pi a^{3}\\right)}}{\\pi^{2} a w^{3}} - \\frac{24 \\, {\\left(5 \\, \\pi a^{5} + 9 \\, \\pi a^{3}\\right)}^{2}}{\\pi^{2} a^{2} w^{3}}\\right)} \\epsilon^{2} + 27648 \\, w + \\frac{1152 \\, {\\left(5 \\, \\pi a^{5} + 9 \\, \\pi a^{3}\\right)} \\epsilon}{\\pi a w}\\right)} t</div>"}︡{"html": "<span class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[0, \\frac{5 \\, \\pi a^{5} + 9 \\, \\pi a^{3}}{24 \\, \\pi a w}, 0, \\frac{5 \\, a^{8}}{27648 \\, w^{3}} + \\frac{{\\left(25 \\, \\pi a^{4} + 18 \\, \\pi a^{2}\\right)} {\\left(5 \\, \\pi a^{5} + 6 \\, \\pi a^{3}\\right)}}{9216 \\, \\pi^{2} a w^{3}} - \\frac{{\\left(5 \\, \\pi a^{5} + 9 \\, \\pi a^{3}\\right)}^{2}}{1152 \\, \\pi^{2} a^{2} w^{3}}\\right]</span>"}︡
︠46b5c4ea-52f4-48e9-93b0-32c6d7eba804︠
print "================================="
print "|| equation2: x''+3x+1/2x^2=0    "
print "================================="
print "epsilon=1/2"
f(x)=x^2
print "f(x,xd)=",f(x)
show(f(x))
krilov_bogolyubov_second_noxd(f,10)
︡df017811-5cd7-4bdb-a5cc-6e7362b9b9fa︡{"stdout": "=================================\n|| equation2: x''+3x+1/2x^2=0    \n=================================\nepsilon=1/2\nf(x,xd)= x^2"}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}x^{2}</div>"}︡{"stdout": "Krilov-Bogolyubov secondt approximation for equation:\n d^2 u/dt+w^2*u=epsilon*f(u);\n f(u)= u^2\nCn[i]="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[\\frac{1}{2} \\, a^{2}, 0, \\frac{1}{2} \\, a^{2}, 0, 0, 0, 0, 0, 0, 0\\right]</div>"}︡{"stdout": "gn="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[-\\frac{1}{2} \\, a^{2}, 0, -\\frac{1}{2} \\, a^{2}, 0, 0, 0, 0, 0, 0, 0\\right]</div>"}︡{"stdout": "A1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "B1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "u1(a,psi)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{a^{2} \\cos\\left(2 \\, \\psi\\right) - 3 \\, a^{2}}{6 \\, w^{2}}</div>"}︡{"stdout": "A2="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "B2="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{5 \\, a^{2}}{12 \\, w^{3}}</div>"}︡{"stdout": "RESULTS:\nda/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "dpsi/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{5 \\, a^{2} \\epsilon^{2}}{12 \\, w^{3}} + w</div>"}︡{"stdout": "x(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{a^{2} \\epsilon \\cos\\left(2 \\, \\psi\\right)}{6 \\, w^{2}} + a \\cos\\left(\\psi\\right) - \\frac{a^{2} \\epsilon}{2 \\, w^{2}}</div>"}︡{"stdout": "where a(t) and psi(t) are obtained from equations above\npsi(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{1}{12} \\, {\\left(\\frac{5 \\, a^{2} \\epsilon^{2}}{w^{3}} - 12 \\, w\\right)} t</div>"}︡{"html": "<span class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[0, 0, 0, -\\frac{5 \\, a^{2}}{12 \\, w^{3}}\\right]</span>"}︡
︠3e32183b-4376-4ab5-af80-c2ff253d8e31︠
def krilov_bogolyubov_second_nox(func,NMAX):
    """
    A function for evaluating second asymptotic approximation of solution for Duffing equation
    u''+w^2*u=epsilon*f(u').
    where arbitrary function F(u,u') depends only on u': u'->F(u') .
    by Krilov-bogolyubov method.
    
    Accepts 2 arguments: 
        \param1 : a function, function is dependent on 1 variable only,
        for example f(ud)=ud^2, where ud -- is a derivative of time-depenent function u(t)
        in Duffing's equation
        \param2 Number of maximal possible fourier series approximation
        
     What is the output?
     It gives you these expressions
     da(t)/dt = epsilon*A1+epsilon^2*A2    ----> whereas a(t)=solution of this diff. eq.(you have to solve)
     dpsi(t)/dt = w+epsilon*B1+epsilon^2*B2  ----> whereas psi(t)=solution of this diff. eq.(you have to solve)
     u1(psi(t)) is calculated
     
     Finally aysmptotic aproximation of solution is given by formula:
         x(t)=a(t)*cos(psi(t))+u1(psi(t))
    """
    
    
    a = var('a')
    w = var('w')
    epsilon = var('epsilon')
    psi=var('psi')
    t=var('t')
    u=var('u')
    ud=var('ud')
    FN=[ ]
    for n in range(NMAX):
        FN.append(1/pi*integrate(func(-a*w*sin(psi))*cos(n*(psi+pi/2.0)),psi,0,2*pi))
    
    if len(FN)<1:
        FN.append(0)
    
    FN[0]=1/(2*pi)*integrate(func(-a*w*sin(psi)),psi,0,2*pi)
    print 'Fn[i]='
    show(FN)
    GN = [ ]
    HN = []
    for n in range(NMAX):
        GN.append(FN[n]*cos(n*pi/2))
        HN.append(-FN[n]*cos(n*pi/2))
    print 'gn[i]='
    show(GN)
    print 'hn[i]='
    show(HN)
    
    
    B1=0
    A1=FN[1]/(2*w)
    print 'B1='
    show(B1)
    print 'A1='
    show(A1)
    
    def u1(a,psi):
        res=0
        for n in range(NMAX):
            if n!=1:
                res+=FN[n]*cos(n*(psi+pi/2))/(n^2-1)
        return -1/w^2*res
    print 'u1(a,psi)='
    show(u1(a,psi))
    
    A2=0
        
    sum=0
    for n in range(2,NMAX):
        if n!=1:
            sum += n*(FN[n])^2/(n^2-1)
    B2=FN[1]/(8*w^3*a)*diff(FN[1],a)-(FN[1])^2/(4*w^3*a^2)-1/(2*w^3*a^2)*sum
    
    print 'A2='
    show(A2)
    print 'B2='
    show(B2)
    
    def dadt(t):
        return epsilon/(2*w)*FN[1]
    def dpsidt(t):
        return w+epsilon*B1+epsilon^2*B2
    def psiint(t):
        return dpsidt(t).integrate(t)
    print "Krilov-Bogolyubov secondt approximation for equation:\n d^2 u/dt+w^2*u=epsilon*f(ud);\n f(ud)=",func(ud),'  ud=du/dt'
    print '\nRESULTS:'
    print 'da/dt(t)='
    show(dadt(t))
    print 'dpsi/dt(t)='
    show(dpsidt(t))
    
    """resulting function x(t)"""     
    def resu(a,psi):
        sum=0
        for n in range(2,NMAX):
            sum+=epsilon/w^2*FN[n]*cos(n*psi)/(n^2-1)
        return a*cos(psi)-epsilon*FN[0]/w^2+sum
    print 'x(t)='
    show(resu(a,psi))
    
    print 'where a(t) and psi(t) are obtained from equations above'
    return 0
︡fd1e6568-0523-4c4f-8537-f16ad8219029︡︡
︠c2b86891-3919-4778-9aa8-73444c67af8c︠
print "========================================"
print "|| equation3: x''+2x+1/2x'^3+1/2x'^5=0    "
print "========================================"
print "epsilon=1/2"
f(xd)=(xd^3+2/3*xd^5)
print "f(x,xd)=",f(xd)
show(f(xd))
krilov_bogolyubov_second_nox(f,NMAX=4)
︡82b38780-cee0-4a8c-acae-77ccbc51ed12︡{"stdout": "========================================\n|| equation3: x''+2x+1/2x'^3+1/2x'^5=0    \n========================================\nepsilon=1/2\nf(x,xd)= 2/3*xd^5 + xd^3"}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{2}{3} \\, \\mbox{xd}^{5} + \\mbox{xd}^{3}</div>"}︡{"stdout": "Fn[i]="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[0, \\frac{5 \\, \\pi a^{5} w^{5} + 9 \\, \\pi a^{3} w^{3}}{12 \\, \\pi}, 0, \\frac{5 \\, \\pi a^{5} w^{5} + 6 \\, \\pi a^{3} w^{3}}{24 \\, \\pi}\\right]</div>"}︡{"stdout": "gn[i]="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[0, 0, 0, 0\\right]</div>"}︡{"stdout": "hn[i]="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[0, 0, 0, 0\\right]</div>"}︡{"stdout": "B1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "A1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{5 \\, \\pi a^{5} w^{5} + 9 \\, \\pi a^{3} w^{3}}{24 \\, \\pi w}</div>"}︡{"stdout": "u1(a,psi)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{{\\left(5 \\, \\pi a^{5} w^{5} + 6 \\, \\pi a^{3} w^{3}\\right)} \\cos\\left(\\frac{3}{2} \\, \\pi + 3 \\, \\psi\\right)}{192 \\, \\pi w^{2}}</div>"}︡{"stdout": "A2="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "B2="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{{\\left(25 \\, \\pi a^{4} w^{5} + 27 \\, \\pi a^{2} w^{3}\\right)} {\\left(5 \\, \\pi a^{5} w^{5} + 9 \\, \\pi a^{3} w^{3}\\right)}}{1152 \\, \\pi^{2} a w^{3}} - \\frac{{\\left(5 \\, \\pi a^{5} w^{5} + 6 \\, \\pi a^{3} w^{3}\\right)}^{2}}{3072 \\, \\pi^{2} a^{2} w^{3}} - \\frac{{\\left(5 \\, \\pi a^{5} w^{5} + 9 \\, \\pi a^{3} w^{3}\\right)}^{2}}{576 \\, \\pi^{2} a^{2} w^{3}}</div>"}︡{"stdout": "Krilov-Bogolyubov secondt approximation for equation:\n d^2 u/dt+w^2*u=epsilon*f(ud);\n f(ud)= 2/3*ud^5 + ud^3   ud=du/dt\n\nRESULTS:\nda/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{{\\left(5 \\, \\pi a^{5} w^{5} + 9 \\, \\pi a^{3} w^{3}\\right)} \\epsilon}{24 \\, \\pi w}</div>"}︡{"stdout": "dpsi/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{1}{9216} \\, {\\left(\\frac{8 \\, {\\left(25 \\, \\pi a^{4} w^{5} + 27 \\, \\pi a^{2} w^{3}\\right)} {\\left(5 \\, \\pi a^{5} w^{5} + 9 \\, \\pi a^{3} w^{3}\\right)}}{\\pi^{2} a w^{3}} - \\frac{3 \\, {\\left(5 \\, \\pi a^{5} w^{5} + 6 \\, \\pi a^{3} w^{3}\\right)}^{2}}{\\pi^{2} a^{2} w^{3}} - \\frac{16 \\, {\\left(5 \\, \\pi a^{5} w^{5} + 9 \\, \\pi a^{3} w^{3}\\right)}^{2}}{\\pi^{2} a^{2} w^{3}}\\right)} \\epsilon^{2} + w</div>"}︡{"stdout": "x(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}a \\cos\\left(\\psi\\right) + \\frac{{\\left(5 \\, \\pi a^{5} w^{5} + 6 \\, \\pi a^{3} w^{3}\\right)} \\epsilon \\cos\\left(3 \\, \\psi\\right)}{192 \\, \\pi w^{2}}</div>"}︡{"stdout": "where a(t) and psi(t) are obtained from equations above"}︡{"html": "<span class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</span>"}︡
︠0433dcd0-5c5a-4a03-9c72-6b64e25e68e7︠
print "================================="
print "|| equation4: x''+2x+1/2x'^2=0    "
print "================================="
print "epsilon=1/2"
f4(xd)=-(xd)^2
print "f(x,xd)=",f4(xd)
show(f4(xd))
krilov_bogolyubov_second_nox(f4,NMAX=4)
︡8ffc7db9-d437-4387-bfbf-f86153f30d0e︡{"stdout": "=================================\n|| equation4: x''+2x+1/2x'^2=0    \n=================================\nepsilon=1/2\nf(x,xd)= -xd^2"}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\mbox{xd}^{2}</div>"}︡{"stdout": "Fn[i]="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[-\\frac{1}{2} \\, a^{2} w^{2}, 0, -\\frac{1}{2} \\, a^{2} w^{2}, 0\\right]</div>"}︡{"stdout": "gn[i]="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[-\\frac{1}{2} \\, a^{2} w^{2}, 0, \\frac{1}{2} \\, a^{2} w^{2}, 0\\right]</div>"}︡{"stdout": "hn[i]="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[\\frac{1}{2} \\, a^{2} w^{2}, 0, -\\frac{1}{2} \\, a^{2} w^{2}, 0\\right]</div>"}︡{"stdout": "B1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "A1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "u1(a,psi)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{a^{2} w^{2} \\cos\\left(\\pi + 2 \\, \\psi\\right) - 3 \\, a^{2} w^{2}}{6 \\, w^{2}}</div>"}︡{"stdout": "A2="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "B2="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{1}{12} \\, a^{2} w</div>"}︡{"stdout": "Krilov-Bogolyubov secondt approximation for equation:\n d^2 u/dt+w^2*u=epsilon*f(ud);\n f(ud)= -ud^2   ud=du/dt\n\nRESULTS:\nda/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "dpsi/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{1}{12} \\, a^{2} \\epsilon^{2} w + w</div>"}︡{"stdout": "x(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{1}{6} \\, a^{2} \\epsilon \\cos\\left(2 \\, \\psi\\right) + \\frac{1}{2} \\, a^{2} \\epsilon + a \\cos\\left(\\psi\\right)</div>"}︡{"stdout": "where a(t) and psi(t) are obtained from equations above"}︡{"html": "<span class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</span>"}︡
︠d2d08ff0-b738-4fd0-9dbc-868e1e809975︠
def auto_oscillation_system_equation(func,NMAX):
    """ a function for evaluating second approximation of equation:
          x''+w^2*x = epsilon*f(x)*dx/dt
          via Krilov-Bogolyubov method.
    Accepts 2 arguments: 
        \param1 : a function, function is dependent on 1 variable only,
        for example f(x)=x^2,
        \param2 Number of maximal possible fourier series approximation
        
     What is the output?
     It gives you these expressions
     da(t)/dt = epsilon*A1+epsilon^2*A2    ----> whereas a(t)=solution of this diff. eq.(you have to solve)
     dpsi(t)/dt = w+epsilon*B1+epsilon^2*B2  ----> whereas psi(t)=solution of this diff. eq.(you have to solve)
     u1(psi(t)) is calculated
     
     Finally aysmptotic aproximation of solution is given by formula:
         x(t)=a(t)*cos(psi(t))+u1(psi(t))
    """
    
    
    a = var('a')
    w = var('w')
    epsilon = var('epsilon')
    psi=var('psi')
    t=var('t')
    u=var('u')
    x=var('x')
    ud=var('ud')
    IFunc = integrate(func(x),x)
    FN=[ 0]
    for n in range(1, NMAX):
        FN.append(1/pi*integrate(IFunc(a*cos(psi))*cos(n*psi),psi,0,2*pi))
    
    if len(FN)<1:
        FN.append(0)
    
    print 'Fn[i]='
    show(FN)
    
    
    B1=0
    A1=FN[1]/(2)
    print 'B1='
    show(B1)
    print 'A1='
    show(A1)
    
    def u1(a,psi):
        sum=0
        for n in range(2,NMAX):
            sum+=n*FN[n]*sin(n*psi)/(n^2-1)
        return epsilon/w*sum
    print 'u1(a,psi)='
    show(u1(a,psi))
    
    A2=0
        
    sum=0
    for n in range(2,NMAX):
        if n!=1:
            sum += n^2*(FN[n])^2/(n^2-1)
    B2=-FN[1]/(8*w*a)*diff(FN[1],a)-1/(2*w*a^2)*sum
    
    print 'A2='
    show(A2)
    print 'B2='
    show(B2)
    
    def dadt(t):
        return epsilon/2*FN[1]
    def dpsidt(t):
        return w
    def psiint(t):
        return dpsidt(t).integrate(t)
    print "Krilov-Bogolyubov secondt approximation for equation:\n x''+w^2*x = epsilon*f(x)*dx/dt;\n f(x)=",func(x)
    print '\nRESULTS:'
    print 'da/dt(t)='
    show(dadt(t))
    print 'dpsi/dt(t)='
    show(dpsidt(t))
    
    """resulting function x(t)"""     
    def resu(a,psi):
        sum=0
        for n in range(2,NMAX):
            sum+=n*FN[n]*sin(n*psi)/(n^2-1)
        return a*cos(psi)+epsilon/w*sum
    print 'x(t)='
    show(resu(a,psi))
    
    print 'where a(t) and psi(t) are obtained from equations above'
    return 0
︡580c00ca-70f7-4428-8b79-20a81a24067c︡︡
︠c007abf7-245c-442b-a7f6-e4fa5dcb67c3︠
print "================================================"
print "|| equation5: x''+2x-1/2x(1-x^2-1/2*x^4)x'=0    "
print "================================================"
print "epsilon=1/2"
f5(x)=(1-x^2-1/2*x^4)
print "f(x,xd)=",f5(x)
show(f5(x))
auto_oscillation_system_equation(f5,NMAX=10)
︡5db39b67-d9a6-4084-b234-df4e33e137f3︡{"stdout": "================================================\n|| equation5: x''+2x-1/2x(1-x^2-1/2*x^4)x'=0    \n================================================\nepsilon=1/2\nf(x,xd)= -1/2*x^4 - x^2 + 1"}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{1}{2} \\, x^{4} - x^{2} + 1</div>"}︡{"stdout": "Fn[i]="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[0, -\\frac{\\pi a^{5} + 4 \\, \\pi a^{3} - 16 \\, \\pi a}{16 \\, \\pi}, 0, -\\frac{3 \\, \\pi a^{5} + 8 \\, \\pi a^{3}}{96 \\, \\pi}, 0, -\\frac{1}{160} \\, a^{5}, 0, 0, 0, 0\\right]</div>"}︡{"stdout": "B1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "A1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{\\pi a^{5} + 4 \\, \\pi a^{3} - 16 \\, \\pi a}{32 \\, \\pi}</div>"}︡{"stdout": "u1(a,psi)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{{\\left(a^{5} \\sin\\left(5 \\, \\psi\\right) + \\frac{3 \\, {\\left(3 \\, \\pi a^{5} + 8 \\, \\pi a^{3}\\right)} \\sin\\left(3 \\, \\psi\\right)}{\\pi}\\right)} \\epsilon}{768 \\, w}</div>"}︡{"stdout": "A2="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "B2="}︡{"stdout": "B2=\n<html><div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{a^{10} + \\frac{3 \\, {\\left(3 \\, \\pi a^{5} + 8 \\, \\pi a^{3}\\right)}^{2}}{\\pi^{2"}︡
︠aa0a4a55-7043-4fbd-b1b3-fb41122243bci︠
%html
49152 \, a^{2} w} + \frac{{\left(\pi a^{5} + 4 \, \pi a^{3} - 16 \, \pi a\right)} {\left(16 \, \pi - 5 \, \pi a^{4} - 12 \, \pi a^{2}\right)}}{2048 \, \pi^{2} a w}</div></html>
Krilov-Bogolyubov secondt approximation for equation:
 x''+w^2*x = epsilon*f(x)*dx/dt;
 f(x)= -1/2*x^4 - x^2 + 1

RESULTS:
da/dt(t)=
<html><div class="math">\newcommand{\Bold}[1]{\mathbf{#1}}-\frac{{\left(\pi a^{5} + 4 \, \pi a^{3} - 16 \, \pi a\right)} \epsilon}{32 \, \pi}</div></html>
dpsi/dt(t)=
<html><div class="math">\newcommand{\Bold}[1]{\mathbf{#1}}w</div></html>
x(t)=
<html><div class="math">\newcommand{\Bold}[1]{\mathbf{#1}}a \cos\left(\psi\right) - \frac{{\left(a^{5} \sin\left(5 \, \psi\right) + \frac{3 \, {\left(3 \, \pi a^{5} + 8 \, \pi a^{3}\right)} \sin\left(3 \, \psi\right)}{\pi}\right)} \epsilon}{768 \, w}</div></html>
where a(t) and psi(t) are obtained from equations above
<html><span class="math">\newcommand{\Bold}[1]{\mathbf{#1}}0</span></html>
}}}

︡4c6391a8-f14b-4a22-97e0-ebea032379d0︡{"html": "49152 \\, a^{2} w} + \\frac{{\\left(\\pi a^{5} + 4 \\, \\pi a^{3} - 16 \\, \\pi a\\right)} {\\left(16 \\, \\pi - 5 \\, \\pi a^{4} - 12 \\, \\pi a^{2}\\right)}}{2048 \\, \\pi^{2} a w}</div></html>\nKrilov-Bogolyubov secondt approximation for equation:\n x''+w^2*x = epsilon*f(x)*dx/dt;\n f(x)= -1/2*x^4 - x^2 + 1\n\nRESULTS:\nda/dt(t)=\n<html><div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{{\\left(\\pi a^{5} + 4 \\, \\pi a^{3} - 16 \\, \\pi a\\right)} \\epsilon}{32 \\, \\pi}</div></html>\ndpsi/dt(t)=\n<html><div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}w</div></html>\nx(t)=\n<html><div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}a \\cos\\left(\\psi\\right) - \\frac{{\\left(a^{5} \\sin\\left(5 \\, \\psi\\right) + \\frac{3 \\, {\\left(3 \\, \\pi a^{5} + 8 \\, \\pi a^{3}\\right)} \\sin\\left(3 \\, \\psi\\right)}{\\pi}\\right)} \\epsilon}{768 \\, w}</div></html>\nwhere a(t) and psi(t) are obtained from equations above\n<html><span class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</span></html>\n}}}"}︡
︠77a47c85-2ab4-439e-973d-0bb50452981d︠
print "================================================"
print "|| equation Van der Pol: x''+x-epsilon*(1-x^2)x'=0    "
print "================================================"
print "epsilon=1/2"
f_Pol(x)=(1-x^2)
print "f(x,xd)=",f_Pol(x)
show(f_Pol(x))
auto_oscillation_system_equation(f_Pol,NMAX=10)
︡57e7ac73-1c94-43a5-96e4-b0d633ec3236︡{"stdout": "================================================\n|| equation Van der Pol: x''+x-epsilon*(1-x^2)x'=0    \n================================================\nepsilon=1/2\nf(x,xd)= -x^2 + 1"}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-x^{2} + 1</div>"}︡{"stdout": "Fn[i]="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[0, -\\frac{\\pi a^{3} - 4 \\, \\pi a}{4 \\, \\pi}, 0, -\\frac{1}{12} \\, a^{3}, 0, 0, 0, 0, 0, 0\\right]</div>"}︡{"stdout": "B1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "A1="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{\\pi a^{3} - 4 \\, \\pi a}{8 \\, \\pi}</div>"}︡{"stdout": "u1(a,psi)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{a^{3} \\epsilon \\sin\\left(3 \\, \\psi\\right)}{32 \\, w}</div>"}︡{"stdout": "A2="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</div>"}︡{"stdout": "B2="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{a^{4}}{256 \\, w} + \\frac{{\\left(\\pi a^{3} - 4 \\, \\pi a\\right)} {\\left(4 \\, \\pi - 3 \\, \\pi a^{2}\\right)}}{128 \\, \\pi^{2} a w}</div>"}︡{"stdout": "Krilov-Bogolyubov secondt approximation for equation:\n x''+w^2*x = epsilon*f(x)*dx/dt;\n f(x)= -x^2 + 1\n\nRESULTS:\nda/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{{\\left(\\pi a^{3} - 4 \\, \\pi a\\right)} \\epsilon}{8 \\, \\pi}</div>"}︡{"stdout": "dpsi/dt(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}w</div>"}︡{"stdout": "x(t)="}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}-\\frac{a^{3} \\epsilon \\sin\\left(3 \\, \\psi\\right)}{32 \\, w} + a \\cos\\left(\\psi\\right)</div>"}︡{"stdout": "where a(t) and psi(t) are obtained from equations above"}︡{"html": "<span class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}0</span>"}︡
